.onAttach <- function(...) {
      packageStartupMessage("BiodiversityR ", utils::packageDescription("BiodiversityR", field="Version"),
      ": Use command BiodiversityRGUI() to launch the Graphical User Interface and to learn about backward compatibility\n")
}




